==> flink-1.14.4-src.tgz: flink-1.14.4/flink-libraries/flink-gelly/src/test/java/org/apache/flink/graph/types/valuearray/NullValueArrayComparatorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.graph.types.valuearray;

import org.apache.flink.api.common.typeutils.ComparatorTestBase;
import org.apache.flink.api.common.typeutils.TypeComparator;
import org.apache.flink.api.common.typeutils.TypeSerializer;
import org.apache.flink.types.NullValue;

/** Tests for {@link NullValueArrayComparator}. */
public class NullValueArrayComparatorTest extends ComparatorTestBase<NullValueArray> {

    @Override
    protected TypeComparator<NullValueArray> createComparator(boolean ascending) {
        return new NullValueArrayComparator(ascending);
    }

    @Override
    protected TypeSerializer<NullValueArray> createSerializer() {
        return new NullValueArraySerializer();
    }

    @Override
    protected NullValueArray[] getSortedTestData() {
        NullValueArray nva0 = new NullValueArray();

        NullValueArray nva1 = new NullValueArray();
        nva1.add(NullValue.getInstance());

        NullValueArray nva2 = new NullValueArray();
        nva2.add(NullValue.getInstance());
        nva2.add(NullValue.getInstance());

        return new NullValueArray[] {nva0, nva1};
    }
}

==> flink-1.16.3-src.tgz: flink-1.16.3/flink-libraries/flink-gelly/src/test/java/org/apache/flink/graph/types/valuearray/NullValueArrayComparatorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.graph.types.valuearray;

import org.apache.flink.api.common.typeutils.ComparatorTestBase;
import org.apache.flink.api.common.typeutils.TypeComparator;
import org.apache.flink.api.common.typeutils.TypeSerializer;
import org.apache.flink.types.NullValue;

/** Tests for {@link NullValueArrayComparator}. */
class NullValueArrayComparatorTest extends ComparatorTestBase<NullValueArray> {

    @Override
    protected TypeComparator<NullValueArray> createComparator(boolean ascending) {
        return new NullValueArrayComparator(ascending);
    }

    @Override
    protected TypeSerializer<NullValueArray> createSerializer() {
        return new NullValueArraySerializer();
    }

    @Override
    protected NullValueArray[] getSortedTestData() {
        NullValueArray nva0 = new NullValueArray();

        NullValueArray nva1 = new NullValueArray();
        nva1.add(NullValue.getInstance());

        NullValueArray nva2 = new NullValueArray();
        nva2.add(NullValue.getInstance());
        nva2.add(NullValue.getInstance());

        return new NullValueArray[] {nva0, nva1};
    }
}
